@@ -1569,7 +1569,8 @@ class DatabaseManager:
             self.run("SET foreign_key_checks = 0;")
 
         success = True
-        for que in query_list:
+        for idx,que in enumerate(query_list):
+            print(f"{idx}/{len(query_list)}",end="\r",flush=True)
             success = self.run(que)
             if success is False:
                 break
@@ -1657,9 +1658,11 @@ class DatabaseManager:
 
         with open(filePath, 'r', encoding='utf-8') as file:
             sql = file.read()
-            sql = _csu.strip_sql_comments(sql)
-            sql = sql.replace(";", ";STATEMENT_END")
-            statements = sql.split('STATEMENT_END')
+            # statements = 
+            statements = [str(x) for x in _csu.sql.get_statements(sql)]
+            # sql = _csu.strip_sql_comments(sql)
+            # sql = sql.replace(";", ";STATEMENT_END")
+            # statements = sql.split('STATEMENT_END')
 
         # self.run("SET foreign_key_checks=0;")
         # "SOURCE /backups/mydump.sql;" -- restore your backup within THIS session
